Kopis512SecretKey

Struct Kopis512SecretKey 

pub struct Kopis512SecretKey(/* private fields */);
A secret key for this KEM

Implementations

Source

impl Kopis512SecretKey

pub fn generate(rng: &mut impl CryptoRng) -> Self

Generate a fresh secret key

pub fn seed(&self) -> &[u8; 32]

Returns the seed that produced this secret key

pub fn expand_from_seed(bytes: &[u8; 32]) -> Self

Deserializes a secret key from a 32-byte seed

pub fn public_key(&self) -> Kopis512PublicKey

Returns the public key corresponding to this secret key

Source

impl Kopis512SecretKey

pub fn decapsulate(&self, encapsulated_key: &Kopis512Ciphertext) -> SharedSecret

Decapsulates an encapsulated key and returns the resulting shared secret. If the encapsulated key is invalid, then the shared secret will be pseudorandom garbage.